import React, { HTMLAttributes, MutableRefObject } from 'react';

/**
 * Properties for the `SmartInput` component.
 */
interface SmartInputProps extends Omit<HTMLAttributes<HTMLDivElement>, 'onChange'> {
    /**
     * The controlled value of the input. Declare a state variable for this in the parent component.
     */
    value: string;
    /**
     * Called whenever the value of the input changes. Use this to update the state variable for the controlled `value` property.
     */
    onChange: (newValue: string) => void;
    /**
     * Renders text the user has input.
     */
    renderText: (props: any) => React.ReactElement<any, any>;
    /**
     * Renders suggested, tab-completable text.
     */
    renderCompletion: (props: any) => React.ReactElement<any, any>;
    /**
     * Renders the placeholder text when the input value is empty.
     * If not provided, the placeholder will be rendered with a regular, low opacity text node.
     */
    renderPlaceholder?: (props: any) => React.ReactElement<any, any>;
    /**
     * The ID of the model to use for completions. If not provided, a sample completion will be displayed.
     */
    modelId?: string;
    /**
     * An object that will be passed to the model when fetching completions. This can be used to provide context for the completions.
     * Pass anything that you think is relevant to making the completions better or more personalized (e.g. the current user id, additional form data, etc.)
     */
    context?: any;
    /**
     * A ref to the underlying contenteditable div. This can be used to focus the editor, select text, etc.
     */
    editorRef?: MutableRefObject<any>;
    /**
     * If true, the input value may contain newline characters. If false, the input value will be foreced to stay a single line.
     */
    multiline?: boolean;
    /**
     * Called when the input loses focus.
     */
    onBlur?: React.FocusEventHandler<HTMLDivElement>;
    /**
     * Called when the input gains focus.
     */
    onFocus?: React.FocusEventHandler<HTMLDivElement>;
    /**
     * Called when a key is pressed while the input is focused.
     */
    onKeyDown?: React.KeyboardEventHandler<HTMLDivElement>;
    /**
     * The value to display when the input is empty.
     */
    placeholder?: string;
    /**
     * Whether to allow the user to edit the input. If false, the input will be read-only.
     */
    disabled?: boolean;
    /**
     * Whether or not to request completions. If true, the input will not request completions and will behave like a normal input.
     * It will still collect data and learn to generate completions.
     */
    safeMode?: boolean;
    /**
     * The CSS styles to apply to the contenteditable div container.
     */
    style?: React.CSSProperties;
    /**
     * The CSS class name to apply to the contenteditable div container.
     */
    className?: string;
    /**
     * If provided, this function will be called to generate a completion instead of fetching one from the model.
     */
    mockCompletion?: (text: string) => string;
    /**
     * If provided, the component will make requests to this URL instead of the default API URL.
     */
    devApiUrl?: string;
}
/**
 * A text input that provides intelligent, tab-completable completions based on the text that has already been entered.
 * Due to the limitations of `<input>` and `<textarea>` elements, this component renders a `<div contenteditable="true">` instead.
 */
declare function SmartInput(p: SmartInputProps): JSX.Element;

export { SmartInput as default };
